Sophie

Sophie

distrib > Scientific%20Linux > 5x > x86_64 > by-pkgid > c9c2ed30f58853bcdbaed4b77a714db9 > files > 1

rhpxl-0.41.1-6.el5.src.rpm

diff -up rhpxl-0.41.1/rhpxl/xhwstate.py.jx rhpxl-0.41.1/rhpxl/xhwstate.py
--- rhpxl-0.41.1/rhpxl/xhwstate.py.jx	2007-05-23 16:33:43.000000000 -0400
+++ rhpxl-0.41.1/rhpxl/xhwstate.py	2008-01-15 10:47:23.000000000 -0500
@@ -98,6 +98,7 @@ def fbinfo():
 
     return struct.unpack('II16xI', result[:28])
 
+# note: this is never called.
 def get_valid_resolution (xserver):
     res_supported = False
 
@@ -513,7 +514,8 @@ class XF86HardwareState:
         l = []
         modes = { 8 : [ "640x480", "800x600" ] }
 
-        if _pyrandr and _pyrandr.randrAvailable():
+	# yeah, this was a bad idea.
+        if False and _pyrandr and _pyrandr.randrAvailable():
             for i in range(0, _pyrandr.getNumRes()):
                 res = "%sx%s" % _pyrandr.getRes(i)
                 found = 0
@@ -530,9 +532,9 @@ class XF86HardwareState:
 
 	# no RANDR, guess wildly
         ram = self.get_videocard_ram_or_probed()
         # If we can't probe, assume at least 8 megs.
         if ram == 0:
-            ram = 8*1024
+            ram = 32*1024
 
         modes[8] = filter (lambda res: resolution_area(res)*1 <= ram*1024, self.all_resolutions)
         modes[16] = filter (lambda res: resolution_area(res)*2 <= ram*1024, self.all_resolutions)
@@ -530,9 +532,9 @@ class XF86HardwareState:
 	# no RANDR, guess wildly
         ram = self.get_videocard_ram_or_probed()
-        # If we can't probe, assume at least 8 megs.
+        # If we can't probe, assume at least 32 megs.
         if ram == 0: